@@ -55,6 +55,7 @@ class account():
     long = None
     location = True
     stopLocation=False
+    savedSearches =[]
     _MCE_SERVICE = 'com.nokia.mce'
     _MCE_REQUEST_PATH = '/com/nokia/mce/request'
     _MCE_REQUEST_IF = 'com.nokia.mce.request'
@@ -172,10 +173,14 @@ class account():
             avatar = avatar.scale_simple(90, 90, gtk.gdk.INTERP_BILINEAR)
             #self.controller.ui.profileImage.set_from_file("/home/user/.witterPics/" + self.accountdata.servicename + "/" + str(user.id)+".jpg")
             self.controller.ui.profileImage.set_from_pixbuf(avatar)  
+            self.getSavedSearches()
         except AttributeError, ae:
             print "Failed to load profile info" 
             print ae
             
+    def clearSearchResults(self):
+        self.searchstore.clear()
+            
     def getAccountData(self):
         return self.accountdata
 
@@ -784,6 +789,10 @@ class account():
         print "performing search"
         #self.searchstore.clear()
         receive_count = 0
+        #if we're not getting older tweets then pay attention to whether we want to clear search results
+        if older==False:
+            if self.controller.search_clear:
+                self.searchstore.clear()
         #when manually triggered use the current text in the entry field
         if (auto == 0):
             searchTerms = self.controller.ui.getEntryText()
@@ -857,6 +866,44 @@ class account():
                 if (auto == 0):
                     note = osso.SystemNote(self.osso_c)
                     note.system_note_dialog("Network error occured. Please try again")
+
+    def getSavedSearches(self, * args):
+        print "getting saved search terms"
+        #self.searchstore.clear()
+        self.savedSearches = []
+        #call search on each of the terms in the search str
+        try:
+            
+            data = self.api.GetSavedSearches()
+
+            
+            print data
+           
+            for x in data:
+                query = x['query']
+                print "found saved search: " + query
+                self.savedSearches.append(query)
+        except IOError, e:
+            msg = 'Error retrieving saved searches results '
+            if hasattr(e, 'reason'):
+                msg = msg + str(e.reason)
+
+            if hasattr(e, 'code'):
+                if (e.code == 401):
+                    reason = "Not authorised: check uid/pwd"
+                elif(e.code == 503):
+                    reason = "Service unavailable"
+                else:
+                    reason = ""
+                msg = msg + 'Server returned ' + str(e.code) + " : " + reason
+            note = osso.SystemNote(self.osso_c)
+            note.system_note_dialog(msg)
+        except httplib.BadStatusLine:
+            print "Network error - BadStatusLine"
+            note = osso.SystemNote(self.osso_c)
+            note.system_note_dialog("Network error occured. Please try again")
+        
+
                 
     def getTrends(self, *args):
 
