@@ -1849,6 +1849,21 @@ class Api(object):
     self._CheckForTwitterError(data)
     return [User.NewFromJsonDict(x) for x in data]
 
+  def GetSavedSearches(self):
+    '''Fetch users saved searches
+
+    The twitter.Api instance must be authenticated.
+
+    Returns:
+      json object with saved searches
+    '''
+    url = 'https://api.twitter.com/1/saved_searches.json'
+    print url
+    json = self._FetchUrl(url)
+    data = simplejson.loads(json)
+    self._CheckForTwitterError(data)
+    return data
+
   def GetUser(self, user):
     '''Returns a single user.
 
