@@ -98,6 +98,7 @@ class Witter():
         self.mentionrefresh = None
         self.publicrefresh = None
         self.searchrefresh = None
+        self.search_clear = False
         self.username = "UserName"
         self.password = ""
         self.bitlyusername = ""
@@ -472,7 +473,14 @@ class Witter():
     	    except ConfigParser.NoOptionError:
     		    print "unknown option"
     	    try:
-    		    self.search_terms = config.get("search", "search_terms")
+                self.search_terms = config.get("search", "search_terms")
+                search_clear = config.get("search", "search_clear")
+                if (search_clear == "True"):
+                    self.search_clear = True
+                    print "clear search results on new search enabled"
+                else:
+                    self.search_clear= False
+                    print "clear search results on new search disabled"
     	    except ConfigParser.NoSectionError:
     		    print "No refresh_interval section"
             except ConfigParser.NoOptionError:
@@ -589,7 +597,10 @@ class Witter():
             f.write("search = " + str(self.searchRefreshInterval) + "\n")
             f.write("[search]\n")
             f.write("search_terms = " + self.search_terms + "\n")
-            
+            if self.search_clear:
+                f.write("search_clear = True\n")
+            else:
+                f.write("search_clear = False\n")
     	except IOError, e:
     		print "failed to write config file"
         try:
@@ -932,13 +943,17 @@ class Witter():
         self.activeAccount.getPublic(auto=autoval, older=get_older, get_count=more)
         self.ui.showBusy(-1)
 
-    def getSearchWrapper(self, get_older=False, autoval=None, more=0, *args):
+    def getSearchWrapper(self, get_older=False, autoval=None, searchTerms=None, more=0, *args):
         self.ui.showBusy(1)
         self.establish_connection()
-        if (autoval == 1):
-            #if we manually his search get the latest content of the search box
-            searchTerms = self.ui.getEntryText()
-        self.activeAccount.getSearch(auto=autoval, searchTerms=self.search_terms, older=get_older, get_count=more)
+        if searchTerms == None:
+            if (autoval == 1):
+                #if we manually his search get the latest content of the search box
+                searchTerms = self.ui.getEntryText()
+            else:
+                searchTerms = self.search_terms
+        print "calling getSearch with " + searchTerms
+        self.activeAccount.getSearch(auto=autoval, searchTerms=searchTerms, older=get_older, get_count=more)
         self.ui.showBusy(-1)
 
 
@@ -972,8 +987,12 @@ class Witter():
         self.ui.showBusy(-1)
         return "done"
 
-
-
+    
+    def searchWrapper(self, widget, searchTerms):
+        print searchTerms
+        refreshtask = witter.RefreshTask(self.getSearchWrapper, 0, None, search_terms=searchTerms)
+        print "refreshing search for " + refreshtask.search_terms
+        refreshtask.refresh()
 
     def getMore(self, more, *args):
         #call the get method for whichever liststore we're viewing
